@@ -1,4 +1,4 @@
-## Copyright (C) 2009-2017 Philip Nienhuis
+## Copyright (C) 2009-2019 Philip Nienhuis
 ##
 ## This program is free software; you can redistribute it and/or modify it under
 ## the terms of the GNU General Public License as published by the Free Software
@@ -128,7 +128,7 @@
 ## Author: Philip Nienhuis <prnienhuis@users.sf.net>
 ## Created 2010-11-03 for Octave
 
-function  [ retval, sinterfaces, loaded_jars ]  = chk_spreadsheet_support (path_to_jars, dbug, path_to_ooo)
+function  [ retval, s_interfaces, jars_loaded ]  = chk_spreadsheet_support (path_to_jars, dbug, path_to_ooo)
 
   ## Keep track of which Java class libs were loaded
   persistent loaded_jars;                   ## Java .jar class libs added to
@@ -145,7 +145,15 @@ function  [ retval, sinterfaces, loaded_jars ]  = chk_spreadsheet_support (path_
     dbug = 0;
   endif
 
-  HAVE_JAVA = __have_feature__ ("JAVA");
+  ## FIXME  Only the first if clause can be retained and the rest of the elseif dropped
+  ##        once io depends on Octave >= 6.0.0. See bug #47480, comments #22 and #25
+  if (compare_versions (OCTAVE_VERSION, "6.0.0", ">="))
+    tmp = javachk ("jvm");
+    HAVE_JAVA = isempty (tmp) || ...
+                isempty (strfind (lower (tmp.identifier), "java-not-supported"));
+  else
+    HAVE_JAVA = __have_feature__ ("JAVA");
+  endif
   if (dbug < 0 && HAVE_JAVA)
     ## Remove loaded Java class libs from the javaclasspath
     if (dbug < -2 && numel (loaded_jars))
@@ -168,6 +176,8 @@ function  [ retval, sinterfaces, loaded_jars ]  = chk_spreadsheet_support (path_
       sinterfaces = [sinterfaces, "COM"];
       retval = 1;
     endif
+    jars_loaded = loaded_jars;
+    s_interfaces = sinterfaces;
     return
   elseif (dbug > 0)
     printf ("\n");
@@ -605,6 +615,9 @@ function  [ retval, sinterfaces, loaded_jars ]  = chk_spreadsheet_support (path_
     endif
   endif
 
+  jars_loaded = loaded_jars;
+  s_interfaces = sinterfaces;
+
 endfunction
 
 
