@@ -1,4 +1,4 @@
-## Copyright (C) 2009-2017 Philip Nienhuis
+## Copyright (C) 2009-2019 Philip Nienhuis
 ##
 ## This program is free software; you can redistribute it and/or modify it under
 ## the terms of the GNU General Public License as published by the Free Software
@@ -147,7 +147,17 @@ function [ ods, rstatus ] = oct2ods (c_arr, ods, wsh=1, crange="", spsh_opts=[])
   elseif (! isempty (crange))
     ## Check for range name and convert it to range & optionally sheet
     ## 1. Check if it matches a range
-    [crange, wsh, ods] = chknmrange (ods, crange, wsh);
+    alfnm = "[abcdefghijklmnopqrstuvwxyz]+[0123456789]+";
+    rlims = cell2mat (cell2mat (regexp (lower (deblank (crange)), ...
+                                ["(^" alfnm ":" alfnm "$|^" alfnm "$)"], "tokens")));
+    if (isempty (rlims))
+      ## 2. Apparently no cell range - check for Named range
+      [crange, wsh, ods] = chknmrange (ods, crange, wsh);
+    else
+      if (isempty (strfind (rlims, ":")))
+        crange = [rlims ":AMJ1048576"];        ## Regular xls limits
+      endif
+    endif
   endif
 
   ## Various options 
