@@ -1,4 +1,4 @@
-## Copyright (C) 2009-2018 Philip Nienhuis
+## Copyright (C) 2009-2019 Philip Nienhuis
 ##
 ## This program is free software; you can redistribute it and/or modify it under
 ## the terms of the GNU General Public License as published by the Free Software
@@ -152,7 +152,21 @@ function [ xls, rstatus ] = oct2xls (obj, xls, wsh=1, crange="", spsh_opts=[])
   elseif (! isempty (crange))
     ## Check for range name and convert it to range & optionally sheet
     ## 1. Check if it matches a range
-    [crange, wsh, xls] = chknmrange (xls, crange, wsh);
+    alfnm = "[abcdefghijklmnopqrstuvwxyz]+[0123456789]+";
+    rlims = cell2mat (cell2mat (regexp (lower (deblank (crange)), ...
+                                ["(^" alfnm ":" alfnm "$|^" alfnm "$)"], "tokens")));
+    if (isempty (rlims))
+      ## Apparently no cell range - check for Named range
+      [crange, wsh, xls] = chknmrange (xls, crange, wsh);
+    else
+      if (isempty (strfind (rlims, ":")))
+        if (strcmpi (xls.filename(end-4:end-1), ".xls"))
+          crange = [rlims ":XFD1048576"];     ## OOXML has ridiculously large limits
+        else
+          crange = [rlims ":IV65536"];        ## Regular xls limits
+        endif
+      endif
+    endif
   endif
 
   ## Various options 
