@@ -1,4 +1,4 @@
-## Copyright (C) 2009-2017 Philip Nienhuis
+## Copyright (C) 2009-2019 Philip Nienhuis
 ##
 ## This program is free software; you can redistribute it and/or modify it under
 ## the terms of the GNU General Public License as published by the Free Software
@@ -29,9 +29,9 @@
 ## @var{wsh} is either numerical or text, in the latter case it is 
 ## case-sensitive and it may be max. 31 characters long.
 ## Note that in case of a numerical @var{wsh} this number refers to the
-## position in the worksheet stack, counted from the left in an Excel
-## window.  The default is numerical 1, i.e. corresponding to the leftmost
-## worksheet tab in the Excel file.
+## position in the total sheet stack, counted from the left in an spreadsheet
+## program window.  The default is numerical 1, i.e. corresponding to the
+## leftmost sheet tab in the spreadsheet file.
 ##
 ## @var{range} is expected to be either a regular spreadsheet range
 ## format, "" (empty string, indicating all data in a worksheet), or a
@@ -145,6 +145,8 @@ function [ rawarr, xls, rstatus ] = xls2oct (xls, wsh=1, datrange="", spsh_opts=
   ## Check worksheet ptr
   if (! (ischar (wsh) || isnumeric (wsh)))
     error ("Integer (index) or text (wsh name) expected for arg # 2\n");
+  elseif (isempty (wsh))
+    wsh = 1;
   endif
 
   ## Check range
@@ -197,11 +199,11 @@ function [ rawarr, xls, rstatus ] = xls2oct (xls, wsh=1, datrange="", spsh_opts=
     [rawarr, xls, rstatus] = __UNO_spsh2oct__ (xls, wsh, datrange, spsh_opts);
   elseif (strcmp (xls.xtype, "OCT"))
     ## Read xls file tru native Octave
-    if (strcmpi (xls.app, 'xlsx'))
+    if (strcmpi (xls.app, "xlsx"))
       [rawarr, xls, rstatus] = __OCT_xlsx2oct__ (xls, wsh, datrange, spsh_opts);
-    elseif (strcmpi (xls.app, 'gnumeric'))
+    elseif (strcmpi (xls.app, "gnumeric"))
       [rawarr, xls, rstatus] = __OCT_gnm2oct__ (xls, wsh, datrange);
-    elseif (strcmpi (xls.app, 'ods'))
+    elseif (strcmpi (xls.app, "ods"))
       [rawarr, xls, rstatus] = __OCT_ods2oct__ (xls, wsh, datrange, spsh_opts);
     else
       error ("xls2oct.m: file format not supported for OCT interface\n");
@@ -221,15 +223,18 @@ function [ rawarr, xls, rstatus ] = xls2oct (xls, wsh=1, datrange="", spsh_opts=
 
   ## Convert from UTF-8 and strip characters that are not supported by Octave
   ## (any chars < 32 or > 255).
-  ## FIXME: Replace with the following when native2unicode is available:
-  ##        rawarr = tidyxml (rawarr, @(str) native2unicode (str, "UTF-8"));
   if (! strcmp (xls.xtype, "COM") && (spsh_opts.convert_utf))
-    rawarr = tidyxml (rawarr, @utf82unicode);
+    if (exist ("native2unicode", "file"))
+      conv_fcn = @(str) unicode2native (native2unicode (str, "UTF-8"));
+    else
+      conv_fcn = @utf82unicode;
+    endif
+    rawarr = tidyxml (rawarr, conv_fcn);
   endif
 
   ## Optionally strip empty outer rows and columns & keep track of original data location
   if (spsh_opts.strip_array)
-    emptr = cellfun ('isempty', rawarr);
+    emptr = cellfun ("isempty", rawarr);
     if (all (all (emptr)))
       rawarr = {};
       xls.limits = [];
